diff --git a/.gitignore b/.gitignore
index 4d61b9286..81642b0e1 100644
--- a/.gitignore
+++ b/.gitignore
@@ -4,15 +4,16 @@ babel
.coverage
_build
_static
-dashed/bin/dashedc
+caravel/bin/caravelc
+envpy3
build
*.db
tmp
-dashed_config.py
+caravel_config.py
local_config.py
env
dist
-dashed.egg-info/
+caravel.egg-info/
app.db
*.bak
diff --git a/.landscape.yml b/.landscape.yml
index 93e2e8d44..48a06e4ce 100644
--- a/.landscape.yml
+++ b/.landscape.yml
@@ -16,8 +16,8 @@ pep8:
full: true
ignore-paths:
- docs
- - dashed/migrations/env.py
- - dashed/ascii_art.py
+ - caravel/migrations/env.py
+ - caravel/ascii_art.py
ignore-patterns:
- ^example/doc_.*\.py$
- (^|/)docs(/|$)
diff --git a/.travis.yml b/.travis.yml
index 7035ea95e..2f22d1c16 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -11,7 +11,7 @@ before_install:
install:
- pip wheel -w $HOME/.wheelhouse -f $HOME/.wheelhouse .
- pip install --find-links=$HOME/.wheelhouse --no-index .
- - cd dashed/assets
+ - cd caravel/assets
- npm install
- npm run lint
- npm run prod
diff --git a/CONTRIBUTING.md b/CONTRIBUTING.md
index 9410d800c..ec80742ac 100644
--- a/CONTRIBUTING.md
+++ b/CONTRIBUTING.md
@@ -30,8 +30,8 @@ Look through the GitHub issues for features. Anything tagged with
### Documentation
-Dashed could always use better documentation,
-whether as part of the official Dashed docs,
+Caravel could always use better documentation,
+whether as part of the official Caravel docs,
in docstrings, `docs/*.rst` or even on the web as blog posts or
articles.
@@ -49,14 +49,14 @@ If you are proposing a feature:
## Latest Documentation
-[API Documentation](http://pythonhosted.com/dashed)
+[API Documentation](http://pythonhosted.com/caravel)
## Setting up a Python development environment
# fork the repo on github and then clone it
# alternatively you may want to clone the main repo but that won't work
# so well if you are planning on sending PRs
- # git clone git@github.com:mistercrunch/dashed.git
+ # git clone git@github.com:mistercrunch/caravel.git
# [optional] setup a virtual env and activate it
virtualenv env
@@ -66,24 +66,24 @@ If you are proposing a feature:
python setup.py develop
# Create an admin user
- fabmanager create-admin --app dashed
+ fabmanager create-admin --app caravel
# Initialize the database
- dashed db upgrade
+ caravel db upgrade
# Create default roles and permissions
- dashed init
+ caravel init
# Load some data to play with
- dashed load_examples
+ caravel load_examples
# start a dev web server
- dashed runserver -d
+ caravel runserver -d
## Setting up the node / npm javascript environment
-`dashed/assets` contains all npm-managed, front end assets.
+`caravel/assets` contains all npm-managed, front end assets.
Flask-Appbuilder itself comes bundled with jQuery and bootstrap.
While these may be phased out over time, these packages are currently not
managed with npm.
@@ -116,7 +116,7 @@ new `node_modules/` folder within `assets/`.
npm install
```
-To parse and generate bundled files for dashed, run either of the
+To parse and generate bundled files for caravel, run either of the
following commands. The `dev` flag will keep the npm script running and
re-run it upon any changes within the assets directory.
@@ -132,7 +132,7 @@ For every development session you will have to start a flask dev server
as well as an npm watcher
```
-dashed runserver -d -p 8081
+caravel runserver -d -p 8081
npm run dev
```
@@ -157,12 +157,12 @@ Generate the documentation with:
cd docs && ./build.sh
## CSS Themes
-As part of the npm build process, CSS for Dashed is compiled from ```Less```, a dynamic stylesheet language.
+As part of the npm build process, CSS for Caravel is compiled from ```Less```, a dynamic stylesheet language.
-It's possible to customize or add your own theme to Dashed, either by overriding CSS rules or preferably
+It's possible to customize or add your own theme to Caravel, either by overriding CSS rules or preferably
by modifying the Less variables or files in ```assets/stylesheets/less/```.
-The ```variables.less``` and ```bootswatch.less``` files that ship with Dashed are derived from
+The ```variables.less``` and ```bootswatch.less``` files that ship with Caravel are derived from
[Bootswatch](https://bootswatch.com) and thus extend Bootstrap. Modify variables in these files directly, or
swap them out entirely with the equivalent files from other Bootswatch (themes)[https://github.com/thomaspark/bootswatch.git]
diff --git a/MANIFEST.in b/MANIFEST.in
index ce0e121d0..72c6b65f0 100644
--- a/MANIFEST.in
+++ b/MANIFEST.in
@@ -1,8 +1,8 @@
-recursive-include dashed/templates *
-recursive-include dashed/static *
-recursive-exclude dashed/static/assets/node_modules *
-recursive-include dashed/static/assets/node_modules/font-awesome *
-recursive-exclude dashed/static/docs *
+recursive-include caravel/templates *
+recursive-include caravel/static *
+recursive-exclude caravel/static/assets/node_modules *
+recursive-include caravel/static/assets/node_modules/font-awesome *
+recursive-exclude caravel/static/docs *
recursive-exclude tests *
-recursive-include dashed/data *
-recursive-include dashed/migrations *
+recursive-include caravel/data *
+recursive-include caravel/migrations *
diff --git a/README.md b/README.md
index 2cbfb9b19..93a831267 100644
--- a/README.md
+++ b/README.md
@@ -1,33 +1,33 @@
-Dashed
+Caravel
=========
-[](https://badge.fury.io/py/dashed)
-[](https://coveralls.io/github/airbnb/dashed?branch=master)
-[](https://landscape.io/github/airbnb/dashed/master)
-[](https://requires.io/github/airbnb/dashed/requirements/?branch=master)
-[](https://gitter.im/airbnb/dashed?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
+[](https://badge.fury.io/py/caravel)
+[](https://coveralls.io/github/airbnb/caravel?branch=master)
+[](https://landscape.io/github/airbnb/caravel/master)
+[](https://requires.io/github/airbnb/caravel/requirements/?branch=master)
+[](https://gitter.im/airbnb/caravel?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
-Dashed is a data exploration platform designed to be visual, intuitive
+Caravel is a data exploration platform designed to be visual, intuitive
and interactive.
[this project used to be named **Panoramix**]
-Video - Introduction to Dashed
+Video - Introduction to Caravel
---------------------------------
-[](http://www.youtube.com/watch?v=3Txm_nj_R7M)
+[](http://www.youtube.com/watch?v=3Txm_nj_R7M)
Screenshots
------------


-Dashed
+Caravel
---------
-Dashed's main goal is to make it easy to slice, dice and visualize data.
+Caravel's main goal is to make it easy to slice, dice and visualize data.
It empowers its user to perform **analytics at the speed of thought**.
-Dashed provides:
+Caravel provides:
* A quick way to intuitively visualize datasets
* Create and share interactive dashboards
* A rich set of visualizations to analyze your data, as well as a flexible
@@ -40,14 +40,14 @@ Dashed provides:
displayed in the UI,
by defining which fields should show up in which dropdown and which
aggregation and function (metrics) are made available to the user
-* Deep integration with Druid allows for Dashed to stay blazing fast while
+* Deep integration with Druid allows for Caravel to stay blazing fast while
slicing and dicing large, realtime datasets
Database Support
----------------
-Dashed was originally designed on to of Druid.io, but quickly broadened
+Caravel was originally designed on to of Druid.io, but quickly broadened
its scope to support other databases through the use of SqlAlchemy, a Python
ORM that is compatible with
[most common databases](http://docs.sqlalchemy.org/en/rel_1_0/core/engines.html).
@@ -68,36 +68,36 @@ power analytic dashboards and applications.*
Installation
------------
-Dashed is currently only tested using Python 2.7.*. Python 3 support is
+Caravel is currently only tested using Python 2.7.*. Python 3 support is
on the roadmap, Python 2.6 won't be supported.
-Follow these few simple steps to install Dashed.
+Follow these few simple steps to install Caravel.
```
-# Install dashed
-pip install dashed
+# Install caravel
+pip install caravel
# Create an admin user
-fabmanager create-admin --app dashed
+fabmanager create-admin --app caravel
# Initialize the database
-dashed db upgrade
+caravel db upgrade
# Create default roles and permissions
-dashed init
+caravel init
# Load some data to play with
-dashed load_examples
+caravel load_examples
# Start the development web server
-dashed runserver -d
+caravel runserver -d
```
After installation, you should be able to point your browser to the right
hostname:port [http://localhost:8088](http://localhost:8088), login using
the credential you entered while creating the admin account, and navigate to
`Menu -> Admin -> Refresh Metadata`. This action should bring in all of
-your datasources for Dashed to be aware of, and they should show up in
+your datasources for Caravel to be aware of, and they should show up in
`Menu -> Datasources`, from where you can start playing with your data!
Configuration
@@ -134,14 +134,14 @@ More screenshots
Related Links
-------------
-* [Dashed Google Group] (https://groups.google.com/forum/#!forum/airbnb_dashed)
-* [Gitter (live chat) Channel](https://gitter.im/airbnb/dashed)
+* [Caravel Google Group] (https://groups.google.com/forum/#!forum/airbnb_caravel)
+* [Gitter (live chat) Channel](https://gitter.im/airbnb/caravel)
Tip of the Hat
--------------
-Dashed would not be possible without these great frameworks / libs
+Caravel would not be possible without these great frameworks / libs
* Flask App Builder - Allowing us to focus on building the app quickly while
getting the foundation for free
@@ -153,4 +153,4 @@ getting the foundation for free
Contributing
------------
-Interested in contributing? Casual hacking? Check out [Contributing.MD](https://github.com/airbnb/dashed/blob/master/CONTRIBUTING.md)
+Interested in contributing? Casual hacking? Check out [Contributing.MD](https://github.com/airbnb/caravel/blob/master/CONTRIBUTING.md)
diff --git a/TODO.md b/TODO.md
index e753f4a5e..25ffabfb4 100644
--- a/TODO.md
+++ b/TODO.md
@@ -1,5 +1,5 @@
# TODO
-List of TODO items for Dashed
+List of TODO items for Caravel
## Important
* **Getting proper JS testing:** unit tests on the Python side are pretty
@@ -7,7 +7,7 @@ List of TODO items for Dashed
testing all the ajax-type calls
* **Viz Plugins:** Allow people to define and share visualization plugins.
ideally one would only need to drop in a set of files in a folder and
- Dashed would discover and expose the plugins
+ Caravel would discover and expose the plugins
## Features
* **Stars:** set dashboards, slices and datasets as favorites
diff --git a/alembic.ini b/alembic.ini
index 6d12b48b5..b5a165360 100644
--- a/alembic.ini
+++ b/alembic.ini
@@ -29,7 +29,7 @@ script_location = migrations
# are written from script.py.mako
# output_encoding = utf-8
-sqlalchemy.url = scheme://localhost/dashed
+sqlalchemy.url = scheme://localhost/caravel
# Logging configuration
[loggers]
diff --git a/dashed/__init__.py b/caravel/__init__.py
similarity index 82%
rename from dashed/__init__.py
rename to caravel/__init__.py
index 6dfc8b2aa..c3517f0c2 100644
--- a/dashed/__init__.py
+++ b/caravel/__init__.py
@@ -10,7 +10,7 @@ from flask.ext.cache import Cache
APP_DIR = os.path.dirname(__file__)
-CONFIG_MODULE = os.environ.get('DASHED_CONFIG', 'dashed.config')
+CONFIG_MODULE = os.environ.get('CARAVEL_CONFIG', 'caravel.config')
# Logging configuration
logging.basicConfig(format='%(asctime)s:%(levelname)s:%(name)s:%(message)s')
@@ -28,15 +28,15 @@ migrate = Migrate(app, db, directory=APP_DIR + "/migrations")
class MyIndexView(IndexView):
@expose('/')
def index(self):
- return redirect('/dashed/welcome')
+ return redirect('/caravel/welcome')
appbuilder = AppBuilder(
app, db.session,
- base_template='dashed/base.html',
+ base_template='caravel/base.html',
indexview=MyIndexView,
security_manager_class=app.config.get("CUSTOM_SECURITY_MANAGER"))
sm = appbuilder.sm
get_session = appbuilder.get_session
-from dashed import config, views # noqa
+from caravel import config, views # noqa
diff --git a/dashed/ascii_art.py b/caravel/ascii_art.py
similarity index 100%
rename from dashed/ascii_art.py
rename to caravel/ascii_art.py
diff --git a/dashed/assets/.babelrc b/caravel/assets/.babelrc
similarity index 100%
rename from dashed/assets/.babelrc
rename to caravel/assets/.babelrc
diff --git a/dashed/assets/.eslintignore b/caravel/assets/.eslintignore
similarity index 100%
rename from dashed/assets/.eslintignore
rename to caravel/assets/.eslintignore
diff --git a/dashed/assets/.eslintrc b/caravel/assets/.eslintrc
similarity index 100%
rename from dashed/assets/.eslintrc
rename to caravel/assets/.eslintrc
diff --git a/dashed/assets/images/bubble.png b/caravel/assets/images/bubble.png
similarity index 100%
rename from dashed/assets/images/bubble.png
rename to caravel/assets/images/bubble.png
diff --git a/dashed/assets/images/dashed_screenshot.png b/caravel/assets/images/caravel_screenshot.png
similarity index 100%
rename from dashed/assets/images/dashed_screenshot.png
rename to caravel/assets/images/caravel_screenshot.png
diff --git a/dashed/assets/images/cardash.jpg b/caravel/assets/images/cardash.jpg
similarity index 100%
rename from dashed/assets/images/cardash.jpg
rename to caravel/assets/images/cardash.jpg
diff --git a/dashed/assets/images/cloud.png b/caravel/assets/images/cloud.png
similarity index 100%
rename from dashed/assets/images/cloud.png
rename to caravel/assets/images/cloud.png
diff --git a/dashed/assets/images/dash.png b/caravel/assets/images/dash.png
similarity index 100%
rename from dashed/assets/images/dash.png
rename to caravel/assets/images/dash.png
diff --git a/dashed/assets/images/favicon.png b/caravel/assets/images/favicon.png
similarity index 100%
rename from dashed/assets/images/favicon.png
rename to caravel/assets/images/favicon.png
diff --git a/dashed/assets/images/gallery.jpg b/caravel/assets/images/gallery.jpg
similarity index 100%
rename from dashed/assets/images/gallery.jpg
rename to caravel/assets/images/gallery.jpg
diff --git a/dashed/assets/images/loading.gif b/caravel/assets/images/loading.gif
similarity index 100%
rename from dashed/assets/images/loading.gif
rename to caravel/assets/images/loading.gif
diff --git a/dashed/assets/images/penguins.png b/caravel/assets/images/penguins.png
similarity index 100%
rename from dashed/assets/images/penguins.png
rename to caravel/assets/images/penguins.png
diff --git a/dashed/assets/images/serpe.jpg b/caravel/assets/images/serpe.jpg
similarity index 100%
rename from dashed/assets/images/serpe.jpg
rename to caravel/assets/images/serpe.jpg
diff --git a/dashed/assets/images/servers.jpg b/caravel/assets/images/servers.jpg
similarity index 100%
rename from dashed/assets/images/servers.jpg
rename to caravel/assets/images/servers.jpg
diff --git a/dashed/assets/images/slice.jpg b/caravel/assets/images/slice.jpg
similarity index 100%
rename from dashed/assets/images/slice.jpg
rename to caravel/assets/images/slice.jpg
diff --git a/dashed/assets/javascripts/dashed-select2.js b/caravel/assets/javascripts/caravel-select2.js
similarity index 100%
rename from dashed/assets/javascripts/dashed-select2.js
rename to caravel/assets/javascripts/caravel-select2.js
diff --git a/dashed/assets/javascripts/css-theme.js b/caravel/assets/javascripts/css-theme.js
similarity index 100%
rename from dashed/assets/javascripts/css-theme.js
rename to caravel/assets/javascripts/css-theme.js
diff --git a/dashed/assets/javascripts/dashboard.js b/caravel/assets/javascripts/dashboard.js
similarity index 98%
rename from dashed/assets/javascripts/dashboard.js
rename to caravel/assets/javascripts/dashboard.js
index 57dccfd6d..e3ef7d545 100644
--- a/dashed/assets/javascripts/dashboard.js
+++ b/caravel/assets/javascripts/dashboard.js
@@ -1,6 +1,6 @@
var $ = window.$ = require('jquery');
var jQuery = window.jQuery = $;
-var px = require('./modules/dashed.js');
+var px = require('./modules/caravel.js');
var d3 = require('d3');
require('bootstrap');
@@ -8,7 +8,7 @@ var ace = require('brace');
require('brace/mode/css');
require('brace/theme/crimson_editor');
-require('./dashed-select2.js');
+require('./caravel-select2.js');
require('../node_modules/gridster/dist/jquery.gridster.min.css');
require('../node_modules/gridster/dist/jquery.gridster.min.js');
@@ -137,7 +137,7 @@ var Dashboard = function (dashboardData) {
};
$.ajax({
type: "POST",
- url: '/dashed/save_dash/' + dashboard.id + '/',
+ url: '/caravel/save_dash/' + dashboard.id + '/',
data: {
data: JSON.stringify(data)
},
diff --git a/dashed/assets/javascripts/explore.js b/caravel/assets/javascripts/explore.js
similarity index 99%
rename from dashed/assets/javascripts/explore.js
rename to caravel/assets/javascripts/explore.js
index 343f53099..ce6f91173 100644
--- a/dashed/assets/javascripts/explore.js
+++ b/caravel/assets/javascripts/explore.js
@@ -5,13 +5,13 @@
// js
var $ = window.$ = require('jquery');
var jQuery = window.jQuery = $;
-var px = require('./modules/dashed.js');
+var px = require('./modules/caravel.js');
require('jquery-ui');
$.widget.bridge('uitooltip', $.ui.tooltip); // Shutting down jq-ui tooltips
require('bootstrap');
-require('./dashed-select2.js');
+require('./caravel-select2.js');
require('../node_modules/bootstrap-toggle/js/bootstrap-toggle.min.js');
diff --git a/dashed/assets/javascripts/index.jsx b/caravel/assets/javascripts/index.jsx
similarity index 94%
rename from dashed/assets/javascripts/index.jsx
rename to caravel/assets/javascripts/index.jsx
index d12ac3d59..c84528c8e 100644
--- a/dashed/assets/javascripts/index.jsx
+++ b/caravel/assets/javascripts/index.jsx
@@ -8,7 +8,7 @@ class App extends React.Component {
render () {
return (
-
Dashed
+
Caravel
Extensible visualization tool for exploring data from any database.
);
diff --git a/dashed/assets/javascripts/modules/utils.js b/caravel/assets/javascripts/modules/utils.js
similarity index 100%
rename from dashed/assets/javascripts/modules/utils.js
rename to caravel/assets/javascripts/modules/utils.js
diff --git a/dashed/assets/javascripts/sql.js b/caravel/assets/javascripts/sql.js
similarity index 93%
rename from dashed/assets/javascripts/sql.js
rename to caravel/assets/javascripts/sql.js
index 7b2fb27c5..40e3145a3 100644
--- a/dashed/assets/javascripts/sql.js
+++ b/caravel/assets/javascripts/sql.js
@@ -36,7 +36,7 @@ $(document).ready(function () {
function showTableMetadata() {
$(".metadata").load(
- '/dashed/table/' + database_id + '/' + $("#dbtable").val() + '/');
+ '/caravel/table/' + database_id + '/' + $("#dbtable").val() + '/');
}
$("#dbtable").on("change", showTableMetadata);
showTableMetadata();
@@ -46,7 +46,7 @@ $(document).ready(function () {
$(".sqlcontent").show();
function selectStarOnClick() {
- $.ajax('/dashed/select_star/' + database_id + '/' + $("#dbtable").val() + '/')
+ $.ajax('/caravel/select_star/' + database_id + '/' + $("#dbtable").val() + '/')
.done(function (msg) {
editor.setValue(msg);
});
@@ -67,7 +67,7 @@ $(document).ready(function () {
history.pushState({}, document.title, '?sql=' + encodeURIComponent(editor.getValue()));
$.ajax({
type: "POST",
- url: '/dashed/runsql/',
+ url: '/caravel/runsql/',
data: {
data: JSON.stringify({
database_id: $('#database_id').val(),
diff --git a/dashed/assets/javascripts/standalone.js b/caravel/assets/javascripts/standalone.js
similarity index 86%
rename from dashed/assets/javascripts/standalone.js
rename to caravel/assets/javascripts/standalone.js
index 9110581f4..efc9f5a90 100644
--- a/dashed/assets/javascripts/standalone.js
+++ b/caravel/assets/javascripts/standalone.js
@@ -1,6 +1,6 @@
var $ = window.$ = require('jquery');
var jQuery = window.jQuery = $;
-var px = require('./modules/dashed.js');
+var px = require('./modules/caravel.js');
require('bootstrap');
diff --git a/dashed/assets/javascripts/welcome.js b/caravel/assets/javascripts/welcome.js
similarity index 94%
rename from dashed/assets/javascripts/welcome.js
rename to caravel/assets/javascripts/welcome.js
index 6d0db5d80..90841313a 100644
--- a/dashed/assets/javascripts/welcome.js
+++ b/caravel/assets/javascripts/welcome.js
@@ -1,7 +1,7 @@
var $ = window.$ = require('jquery');
var jQuery = window.jQuery = $;
-require('../stylesheets/dashed.css');
+require('../stylesheets/caravel.css');
require('../stylesheets/welcome.css');
require('bootstrap');
require('datatables');
@@ -37,7 +37,7 @@ $(document).ready(function () {
cal.init({
start: new Date().setFullYear(new Date().getFullYear() - 1),
range: 13,
- data: '/dashed/activity_per_day',
+ data: '/caravel/activity_per_day',
domain: "month",
subDomain: "day",
itemName: "action",
diff --git a/dashed/assets/package.json b/caravel/assets/package.json
similarity index 89%
rename from dashed/assets/package.json
rename to caravel/assets/package.json
index 606bec806..fec1f7794 100644
--- a/dashed/assets/package.json
+++ b/caravel/assets/package.json
@@ -1,5 +1,5 @@
{
- "name": "dashed",
+ "name": "caravel",
"version": "0.1.0",
"description": "Any database to any visualization",
"directories": {
@@ -15,7 +15,7 @@
},
"repository": {
"type": "git",
- "url": "git+https://github.com/mistercrunch/dashed.git"
+ "url": "git+https://github.com/mistercrunch/caravel.git"
},
"keywords": [
"big",
@@ -31,9 +31,9 @@
],
"author": "Airbnb",
"bugs": {
- "url": "https://github.com/mistercrunch/dashed/issues"
+ "url": "https://github.com/mistercrunch/caravel/issues"
},
- "homepage": "https://github.com/mistercrunch/dashed#readme",
+ "homepage": "https://github.com/mistercrunch/caravel#readme",
"dependencies": {
"babel-loader": "^6.2.1",
"babel-polyfill": "^6.3.14",
diff --git a/dashed/assets/stylesheets/dashed.css b/caravel/assets/stylesheets/caravel.css
similarity index 100%
rename from dashed/assets/stylesheets/dashed.css
rename to caravel/assets/stylesheets/caravel.css
diff --git a/dashed/assets/stylesheets/fonts/glyphicons-halflings-regular.ttf b/caravel/assets/stylesheets/fonts/glyphicons-halflings-regular.ttf
similarity index 100%
rename from dashed/assets/stylesheets/fonts/glyphicons-halflings-regular.ttf
rename to caravel/assets/stylesheets/fonts/glyphicons-halflings-regular.ttf
diff --git a/dashed/assets/stylesheets/fonts/glyphicons-halflings-regular.woff b/caravel/assets/stylesheets/fonts/glyphicons-halflings-regular.woff
similarity index 100%
rename from dashed/assets/stylesheets/fonts/glyphicons-halflings-regular.woff
rename to caravel/assets/stylesheets/fonts/glyphicons-halflings-regular.woff
diff --git a/dashed/assets/stylesheets/fonts/glyphicons-halflings-regular.woff2 b/caravel/assets/stylesheets/fonts/glyphicons-halflings-regular.woff2
similarity index 100%
rename from dashed/assets/stylesheets/fonts/glyphicons-halflings-regular.woff2
rename to caravel/assets/stylesheets/fonts/glyphicons-halflings-regular.woff2
diff --git a/dashed/assets/stylesheets/less/bootswatch.less b/caravel/assets/stylesheets/less/bootswatch.less
similarity index 100%
rename from dashed/assets/stylesheets/less/bootswatch.less
rename to caravel/assets/stylesheets/less/bootswatch.less
diff --git a/dashed/assets/stylesheets/less/index.less b/caravel/assets/stylesheets/less/index.less
similarity index 100%
rename from dashed/assets/stylesheets/less/index.less
rename to caravel/assets/stylesheets/less/index.less
diff --git a/dashed/assets/stylesheets/less/variables.less b/caravel/assets/stylesheets/less/variables.less
similarity index 100%
rename from dashed/assets/stylesheets/less/variables.less
rename to caravel/assets/stylesheets/less/variables.less
diff --git a/dashed/assets/stylesheets/welcome.css b/caravel/assets/stylesheets/welcome.css
similarity index 100%
rename from dashed/assets/stylesheets/welcome.css
rename to caravel/assets/stylesheets/welcome.css
diff --git a/dashed/assets/vendor/parallel_coordinates/d3.parcoords.css b/caravel/assets/vendor/parallel_coordinates/d3.parcoords.css
similarity index 100%
rename from dashed/assets/vendor/parallel_coordinates/d3.parcoords.css
rename to caravel/assets/vendor/parallel_coordinates/d3.parcoords.css
diff --git a/dashed/assets/vendor/parallel_coordinates/d3.parcoords.js b/caravel/assets/vendor/parallel_coordinates/d3.parcoords.js
similarity index 100%
rename from dashed/assets/vendor/parallel_coordinates/d3.parcoords.js
rename to caravel/assets/vendor/parallel_coordinates/d3.parcoords.js
diff --git a/dashed/assets/vendor/parallel_coordinates/divgrid.js b/caravel/assets/vendor/parallel_coordinates/divgrid.js
similarity index 100%
rename from dashed/assets/vendor/parallel_coordinates/divgrid.js
rename to caravel/assets/vendor/parallel_coordinates/divgrid.js
diff --git a/dashed/assets/vendor/pygments.css b/caravel/assets/vendor/pygments.css
similarity index 100%
rename from dashed/assets/vendor/pygments.css
rename to caravel/assets/vendor/pygments.css
diff --git a/dashed/assets/vendor/select2.sortable.js b/caravel/assets/vendor/select2.sortable.js
similarity index 100%
rename from dashed/assets/vendor/select2.sortable.js
rename to caravel/assets/vendor/select2.sortable.js
diff --git a/dashed/assets/visualizations/big_number.css b/caravel/assets/visualizations/big_number.css
similarity index 100%
rename from dashed/assets/visualizations/big_number.css
rename to caravel/assets/visualizations/big_number.css
diff --git a/dashed/assets/visualizations/big_number.js b/caravel/assets/visualizations/big_number.js
similarity index 98%
rename from dashed/assets/visualizations/big_number.js
rename to caravel/assets/visualizations/big_number.js
index 38c22aa89..a9d2b6331 100644
--- a/dashed/assets/visualizations/big_number.js
+++ b/caravel/assets/visualizations/big_number.js
@@ -4,7 +4,7 @@ var d3 = window.d3 || require('d3');
// CSS
require('./big_number.css');
-var px = require('../javascripts/modules/dashed.js');
+var px = require('../javascripts/modules/caravel.js');
function bigNumberVis(slice) {
var div = d3.select(slice.selector);
diff --git a/dashed/assets/visualizations/directed_force.css b/caravel/assets/visualizations/directed_force.css
similarity index 100%
rename from dashed/assets/visualizations/directed_force.css
rename to caravel/assets/visualizations/directed_force.css
diff --git a/dashed/assets/visualizations/directed_force.js b/caravel/assets/visualizations/directed_force.js
similarity index 100%
rename from dashed/assets/visualizations/directed_force.js
rename to caravel/assets/visualizations/directed_force.js
diff --git a/dashed/assets/visualizations/filter_box.css b/caravel/assets/visualizations/filter_box.css
similarity index 82%
rename from dashed/assets/visualizations/filter_box.css
rename to caravel/assets/visualizations/filter_box.css
index 156978361..efe69c538 100644
--- a/dashed/assets/visualizations/filter_box.css
+++ b/caravel/assets/visualizations/filter_box.css
@@ -1,6 +1,6 @@
.select2-highlighted > .filter_box {
background-color: transparent;
- border: 1px dashed black;
+ border: 1px caravel black;
}
.dashboard .filter_box .slice_container > div {
diff --git a/dashed/assets/visualizations/filter_box.js b/caravel/assets/visualizations/filter_box.js
similarity index 98%
rename from dashed/assets/visualizations/filter_box.js
rename to caravel/assets/visualizations/filter_box.js
index f82054961..df6cf99b1 100644
--- a/dashed/assets/visualizations/filter_box.js
+++ b/caravel/assets/visualizations/filter_box.js
@@ -5,7 +5,7 @@ var d3 = window.d3 || require('d3');
// CSS
require('./filter_box.css');
-require('../javascripts/dashed-select2.js');
+require('../javascripts/caravel-select2.js');
function filterBox(slice) {
var filtersObj = {};
diff --git a/dashed/assets/visualizations/heatmap.css b/caravel/assets/visualizations/heatmap.css
similarity index 100%
rename from dashed/assets/visualizations/heatmap.css
rename to caravel/assets/visualizations/heatmap.css
diff --git a/dashed/assets/visualizations/heatmap.js b/caravel/assets/visualizations/heatmap.js
similarity index 98%
rename from dashed/assets/visualizations/heatmap.js
rename to caravel/assets/visualizations/heatmap.js
index 6bc688fc8..c9100e2c0 100644
--- a/dashed/assets/visualizations/heatmap.js
+++ b/caravel/assets/visualizations/heatmap.js
@@ -1,6 +1,6 @@
// JS
var $ = window.$ || require('jquery');
-var px = window.px || require('../javascripts/modules/dashed.js');
+var px = window.px || require('../javascripts/modules/caravel.js');
var d3 = require('d3');
d3.tip = require('d3-tip'); //using window.d3 doesn't capture events properly bc of multiple instances
diff --git a/dashed/assets/visualizations/iframe.js b/caravel/assets/visualizations/iframe.js
similarity index 100%
rename from dashed/assets/visualizations/iframe.js
rename to caravel/assets/visualizations/iframe.js
diff --git a/dashed/assets/visualizations/markup.js b/caravel/assets/visualizations/markup.js
similarity index 100%
rename from dashed/assets/visualizations/markup.js
rename to caravel/assets/visualizations/markup.js
diff --git a/dashed/assets/visualizations/nvd3_vis.css b/caravel/assets/visualizations/nvd3_vis.css
similarity index 86%
rename from dashed/assets/visualizations/nvd3_vis.css
rename to caravel/assets/visualizations/nvd3_vis.css
index 80c452b4d..0d63c69ba 100644
--- a/dashed/assets/visualizations/nvd3_vis.css
+++ b/caravel/assets/visualizations/nvd3_vis.css
@@ -1,4 +1,4 @@
-g.dashed path {
+g.caravel path {
stroke-dasharray: 5, 5;
}
diff --git a/dashed/assets/visualizations/nvd3_vis.js b/caravel/assets/visualizations/nvd3_vis.js
similarity index 99%
rename from dashed/assets/visualizations/nvd3_vis.js
rename to caravel/assets/visualizations/nvd3_vis.js
index f7c61f6e8..db4099456 100644
--- a/dashed/assets/visualizations/nvd3_vis.js
+++ b/caravel/assets/visualizations/nvd3_vis.js
@@ -1,7 +1,7 @@
// JS
var $ = window.$ || require('jquery');
var d3 = window.d3 || require('d3');
-var px = window.px || require('../javascripts/modules/dashed.js');
+var px = window.px || require('../javascripts/modules/caravel.js');
var nv = require('nvd3');
// CSS
diff --git a/dashed/assets/visualizations/parallel_coordinates.js b/caravel/assets/visualizations/parallel_coordinates.js
similarity index 100%
rename from dashed/assets/visualizations/parallel_coordinates.js
rename to caravel/assets/visualizations/parallel_coordinates.js
diff --git a/dashed/assets/visualizations/pivot_table.css b/caravel/assets/visualizations/pivot_table.css
similarity index 100%
rename from dashed/assets/visualizations/pivot_table.css
rename to caravel/assets/visualizations/pivot_table.css
diff --git a/dashed/assets/visualizations/pivot_table.js b/caravel/assets/visualizations/pivot_table.js
similarity index 100%
rename from dashed/assets/visualizations/pivot_table.js
rename to caravel/assets/visualizations/pivot_table.js
diff --git a/dashed/assets/visualizations/sankey.css b/caravel/assets/visualizations/sankey.css
similarity index 100%
rename from dashed/assets/visualizations/sankey.css
rename to caravel/assets/visualizations/sankey.css
diff --git a/dashed/assets/visualizations/sankey.js b/caravel/assets/visualizations/sankey.js
similarity index 98%
rename from dashed/assets/visualizations/sankey.js
rename to caravel/assets/visualizations/sankey.js
index 018ffe57d..1272f59fc 100644
--- a/dashed/assets/visualizations/sankey.js
+++ b/caravel/assets/visualizations/sankey.js
@@ -1,7 +1,7 @@
// CSS
require('./sankey.css');
// JS
-var px = window.px || require('../javascripts/modules/dashed.js');
+var px = window.px || require('../javascripts/modules/caravel.js');
var d3 = window.d3 || require('d3');
d3.sankey = require('d3-sankey').sankey;
diff --git a/dashed/assets/visualizations/sunburst.css b/caravel/assets/visualizations/sunburst.css
similarity index 100%
rename from dashed/assets/visualizations/sunburst.css
rename to caravel/assets/visualizations/sunburst.css
diff --git a/dashed/assets/visualizations/sunburst.js b/caravel/assets/visualizations/sunburst.js
similarity index 99%
rename from dashed/assets/visualizations/sunburst.js
rename to caravel/assets/visualizations/sunburst.js
index 8246454c2..f5ad84b0c 100644
--- a/dashed/assets/visualizations/sunburst.js
+++ b/caravel/assets/visualizations/sunburst.js
@@ -1,5 +1,5 @@
var d3 = window.d3 || require('d3');
-var px = require('../javascripts/modules/dashed.js');
+var px = require('../javascripts/modules/caravel.js');
var wrapSvgText = require('../javascripts/modules/utils.js').wrapSvgText;
require('./sunburst.css');
diff --git a/dashed/assets/visualizations/table.css b/caravel/assets/visualizations/table.css
similarity index 100%
rename from dashed/assets/visualizations/table.css
rename to caravel/assets/visualizations/table.css
diff --git a/dashed/assets/visualizations/table.js b/caravel/assets/visualizations/table.js
similarity index 100%
rename from dashed/assets/visualizations/table.js
rename to caravel/assets/visualizations/table.js
diff --git a/dashed/assets/visualizations/word_cloud.js b/caravel/assets/visualizations/word_cloud.js
similarity index 97%
rename from dashed/assets/visualizations/word_cloud.js
rename to caravel/assets/visualizations/word_cloud.js
index a83442ba5..7efd7c031 100644
--- a/dashed/assets/visualizations/word_cloud.js
+++ b/caravel/assets/visualizations/word_cloud.js
@@ -1,4 +1,4 @@
-var px = window.px || require('../javascripts/modules/dashed.js');
+var px = window.px || require('../javascripts/modules/caravel.js');
var d3 = window.d3 || require('d3');
var cloudLayout = require('d3-cloud');
diff --git a/dashed/assets/visualizations/world_map.css b/caravel/assets/visualizations/world_map.css
similarity index 100%
rename from dashed/assets/visualizations/world_map.css
rename to caravel/assets/visualizations/world_map.css
diff --git a/dashed/assets/visualizations/world_map.js b/caravel/assets/visualizations/world_map.js
similarity index 100%
rename from dashed/assets/visualizations/world_map.js
rename to caravel/assets/visualizations/world_map.js
diff --git a/dashed/assets/webpack.config.js b/caravel/assets/webpack.config.js
similarity index 100%
rename from dashed/assets/webpack.config.js
rename to caravel/assets/webpack.config.js
diff --git a/dashed/bin/__init__.py b/caravel/bin/__init__.py
similarity index 100%
rename from dashed/bin/__init__.py
rename to caravel/bin/__init__.py
diff --git a/dashed/bin/dashed b/caravel/bin/caravel
similarity index 82%
rename from dashed/bin/dashed
rename to caravel/bin/caravel
index 9640a49c5..5400b9495 100755
--- a/dashed/bin/dashed
+++ b/caravel/bin/caravel
@@ -5,11 +5,11 @@ import logging
from subprocess import Popen
from flask.ext.script import Manager
-from dashed import app
+from caravel import app
from flask.ext.migrate import MigrateCommand
-import dashed
-from dashed import db
-from dashed import data, utils
+import caravel
+from caravel import db
+from caravel import data, utils
config = app.config
@@ -21,16 +21,16 @@ manager.add_command('db', MigrateCommand)
'-d', '--debug', action='store_true',
help="Start the web server in debug mode")
@manager.option(
- '-p', '--port', default=config.get("DASHED_WEBSERVER_PORT"),
+ '-p', '--port', default=config.get("CARAVEL_WEBSERVER_PORT"),
help="Specify the port on which to run the web server")
@manager.option(
- '-w', '--workers', default=config.get("DASHED_WORKERS", 16),
+ '-w', '--workers', default=config.get("CARAVEL_WORKERS", 16),
help="Number of gunicorn web server workers to fire up")
@manager.option(
- '-t', '--timeout', default=config.get("DASHED_WEBSERVER_TIMEOUT"),
+ '-t', '--timeout', default=config.get("CARAVEL_WEBSERVER_TIMEOUT"),
help="Specify the timeout (seconds) for the gunicorn web server")
def runserver(debug, port, timeout, workers):
- """Starts a Dashed web server"""
+ """Starts a Caravel web server"""
debug = debug or config.get("DEBUG")
if debug:
app.run(
@@ -43,14 +43,14 @@ def runserver(debug, port, timeout, workers):
"-w {workers} "
"--timeout {timeout} "
"-b 0.0.0.0:{port} "
- "dashed:app").format(**locals())
+ "caravel:app").format(**locals())
print("Starting server with command: " + cmd)
Popen(cmd, shell=True).wait()
@manager.command
def init():
- """Inits the Dashed application"""
- utils.init(dashed)
+ """Inits the Caravel application"""
+ utils.init(caravel)
@manager.option(
'-s', '--sample', action='store_true',
@@ -74,7 +74,7 @@ def load_examples(sample):
def refresh_druid():
"""Refresh all druid datasources"""
session = db.session()
- from dashed import models
+ from caravel import models
for cluster in session.query(models.DruidCluster).all():
try:
cluster.refresh_datasources()
diff --git a/dashed/static/assets b/caravel/static/assets
similarity index 100%
rename from dashed/static/assets
rename to caravel/static/assets
diff --git a/dashed/static/docs b/caravel/static/docs
similarity index 100%
rename from dashed/static/docs
rename to caravel/static/docs
diff --git a/dashed/templates/appbuilder/baselayout.html b/caravel/templates/appbuilder/baselayout.html
similarity index 100%
rename from dashed/templates/appbuilder/baselayout.html
rename to caravel/templates/appbuilder/baselayout.html
diff --git a/dashed/templates/appbuilder/general/widgets/list.html b/caravel/templates/appbuilder/general/widgets/list.html
similarity index 94%
rename from dashed/templates/appbuilder/general/widgets/list.html
rename to caravel/templates/appbuilder/general/widgets/list.html
index b0c28eda9..51c958772 100644
--- a/dashed/templates/appbuilder/general/widgets/list.html
+++ b/caravel/templates/appbuilder/general/widgets/list.html
@@ -64,7 +64,7 @@
{{'checked' if item[value] }}
name="{{ '{}__{}'.format(pk, value) }}"
id="{{ '{}__{}'.format(pk, value) }}"
- onchange="$.get('/dashed/checkbox/{{ modelview_name }}/{{ pk }}/{{ value }}/' + $('#{{ '{}__{}'.format(pk, value) }}')[0].checked ) + '/';">
+ onchange="$.get('/caravel/checkbox/{{ modelview_name }}/{{ pk }}/{{ value }}/' + $('#{{ '{}__{}'.format(pk, value) }}')[0].checked ) + '/';">
{% else %}
{{ item[value]|safe }}
{% endif %}
diff --git a/dashed/templates/appbuilder/navbar.html b/caravel/templates/appbuilder/navbar.html
similarity index 100%
rename from dashed/templates/appbuilder/navbar.html
rename to caravel/templates/appbuilder/navbar.html
diff --git a/dashed/templates/appbuilder/navbar_right.html b/caravel/templates/appbuilder/navbar_right.html
similarity index 100%
rename from dashed/templates/appbuilder/navbar_right.html
rename to caravel/templates/appbuilder/navbar_right.html
diff --git a/dashed/templates/dashed/ajah.html b/caravel/templates/caravel/ajah.html
similarity index 100%
rename from dashed/templates/dashed/ajah.html
rename to caravel/templates/caravel/ajah.html
diff --git a/dashed/templates/dashed/base.html b/caravel/templates/caravel/base.html
similarity index 92%
rename from dashed/templates/dashed/base.html
rename to caravel/templates/caravel/base.html
index 9ac1eef96..bab571bbc 100644
--- a/dashed/templates/dashed/base.html
+++ b/caravel/templates/caravel/base.html
@@ -2,7 +2,7 @@
{% block head_css %}
-
+
{{super()}}
{% endblock %}
diff --git a/dashed/templates/dashed/basic.html b/caravel/templates/caravel/basic.html
similarity index 100%
rename from dashed/templates/dashed/basic.html
rename to caravel/templates/caravel/basic.html
diff --git a/dashed/templates/dashed/dashboard.html b/caravel/templates/caravel/dashboard.html
similarity index 99%
rename from dashed/templates/dashed/dashboard.html
rename to caravel/templates/caravel/dashboard.html
index a4ff39b42..9859fc77e 100644
--- a/dashed/templates/dashed/dashboard.html
+++ b/caravel/templates/caravel/dashboard.html
@@ -1,4 +1,4 @@
-{% extends "dashed/basic.html" %}
+{% extends "caravel/basic.html" %}
{% block head_js %}
{{ super() }}
diff --git a/dashed/templates/dashed/explore.html b/caravel/templates/caravel/explore.html
similarity index 99%
rename from dashed/templates/dashed/explore.html
rename to caravel/templates/caravel/explore.html
index c2519f246..a8fe55f7e 100644
--- a/dashed/templates/dashed/explore.html
+++ b/caravel/templates/caravel/explore.html
@@ -1,4 +1,4 @@
-{% extends "dashed/basic.html" %}
+{% extends "caravel/basic.html" %}
{% block title %}
{% if slice %}
diff --git a/dashed/templates/dashed/index.html b/caravel/templates/caravel/index.html
similarity index 78%
rename from dashed/templates/dashed/index.html
rename to caravel/templates/caravel/index.html
index 71ed52780..1c82a1df8 100644
--- a/dashed/templates/dashed/index.html
+++ b/caravel/templates/caravel/index.html
@@ -1,4 +1,4 @@
-{% extends "dashed/basic.html" %}
+{% extends "caravel/basic.html" %}
{% block tail_js %}
{{ super() }}
diff --git a/dashed/templates/dashed/models/database/add.html b/caravel/templates/caravel/models/database/add.html
similarity index 67%
rename from dashed/templates/dashed/models/database/add.html
rename to caravel/templates/caravel/models/database/add.html
index 79b6cf6cb..f4388ece3 100644
--- a/dashed/templates/dashed/models/database/add.html
+++ b/caravel/templates/caravel/models/database/add.html
@@ -1,6 +1,6 @@
{% extends "appbuilder/general/model/add.html" %}
-{% import "dashed/models/database/macros.html" as macros %}
+{% import "caravel/models/database/macros.html" as macros %}
{% block tail_js %}
{{ super() }}
{{ macros.testconn() }}
diff --git a/dashed/templates/dashed/models/database/edit.html b/caravel/templates/caravel/models/database/edit.html
similarity index 67%
rename from dashed/templates/dashed/models/database/edit.html
rename to caravel/templates/caravel/models/database/edit.html
index b1db50f2b..46a3693bb 100644
--- a/dashed/templates/dashed/models/database/edit.html
+++ b/caravel/templates/caravel/models/database/edit.html
@@ -1,6 +1,6 @@
{% extends "appbuilder/general/model/edit.html" %}
-{% import "dashed/models/database/macros.html" as macros %}
+{% import "caravel/models/database/macros.html" as macros %}
{% block tail_js %}
{{ super() }}
{{ macros.testconn() }}
diff --git a/dashed/templates/dashed/models/database/macros.html b/caravel/templates/caravel/models/database/macros.html
similarity index 96%
rename from dashed/templates/dashed/models/database/macros.html
rename to caravel/templates/caravel/models/database/macros.html
index dac8b6d50..c06687061 100644
--- a/dashed/templates/dashed/models/database/macros.html
+++ b/caravel/templates/caravel/models/database/macros.html
@@ -3,7 +3,7 @@
$("#sqlalchemy_uri").parent()
.append('');
$("#testconn").click(function() {
- var url = "/dashed/testconn";
+ var url = "/caravel/testconn";
$.ajax({
method: "POST",
url: url,
diff --git a/dashed/templates/dashed/no_data.html b/caravel/templates/caravel/no_data.html
similarity index 72%
rename from dashed/templates/dashed/no_data.html
rename to caravel/templates/caravel/no_data.html
index a8de807a6..a846e9b8e 100644
--- a/dashed/templates/dashed/no_data.html
+++ b/caravel/templates/caravel/no_data.html
@@ -1,4 +1,4 @@
-{% extends "dashed/datasource.html" %}
+{% extends "caravel/datasource.html" %}
{% block viz %}
No data: review your incantations.
diff --git a/dashed/templates/dashed/sql.html b/caravel/templates/caravel/sql.html
similarity index 98%
rename from dashed/templates/dashed/sql.html
rename to caravel/templates/caravel/sql.html
index fd660eac3..683de3bcc 100644
--- a/dashed/templates/dashed/sql.html
+++ b/caravel/templates/caravel/sql.html
@@ -1,4 +1,4 @@
-{% extends "dashed/basic.html" %}
+{% extends "caravel/basic.html" %}
{% block head_css %}
{{super()}}
diff --git a/dashed/templates/dashed/standalone.html b/caravel/templates/caravel/standalone.html
similarity index 96%
rename from dashed/templates/dashed/standalone.html
rename to caravel/templates/caravel/standalone.html
index 319aad13c..d159fc0fe 100644
--- a/dashed/templates/dashed/standalone.html
+++ b/caravel/templates/caravel/standalone.html
@@ -1,7 +1,7 @@
-
+
{% set CSS_THEME = appbuilder.get_app.config.get("CSS_THEME") %}
{% set height = request.args.get("height", 700) %}
{% if CSS_THEME %}
diff --git a/dashed/templates/dashed/traceback.html b/caravel/templates/caravel/traceback.html
similarity index 100%
rename from dashed/templates/dashed/traceback.html
rename to caravel/templates/caravel/traceback.html
diff --git a/dashed/templates/dashed/welcome.html b/caravel/templates/caravel/welcome.html
similarity index 96%
rename from dashed/templates/dashed/welcome.html
rename to caravel/templates/caravel/welcome.html
index 6184a2481..efafb86f3 100644
--- a/dashed/templates/dashed/welcome.html
+++ b/caravel/templates/caravel/welcome.html
@@ -1,4 +1,4 @@
-{% extends "dashed/basic.html" %}
+{% extends "caravel/basic.html" %}
{% block head_js %}
{{ super() }}
diff --git a/dashed/templates/index.html b/caravel/templates/index.html
similarity index 99%
rename from dashed/templates/index.html
rename to caravel/templates/index.html
index e2f16ba7e..5bded9cb6 100644
--- a/dashed/templates/index.html
+++ b/caravel/templates/index.html
@@ -18,7 +18,7 @@
-
Dashed
+
Caravel
an open source data visualization platform
diff --git a/dashed/viz.py b/caravel/viz.py
similarity index 99%
rename from dashed/viz.py
rename to caravel/viz.py
index e313ab976..797c5363e 100644
--- a/dashed/viz.py
+++ b/caravel/viz.py
@@ -1,7 +1,7 @@
"""This module contains the "Viz" objects
These objects represent the backend of all the visualizations that
-Dashed can render.
+Caravel can render.
"""
from collections import OrderedDict, defaultdict
@@ -17,8 +17,8 @@ from werkzeug.datastructures import ImmutableMultiDict
from werkzeug.urls import Href
import pandas as pd
-from dashed import app, utils, cache
-from dashed.forms import FormFactory
+from caravel import app, utils, cache
+from caravel.forms import FormFactory
from six import string_types
@@ -116,7 +116,7 @@ class BaseViz(object):
if d[key] is False:
del d[key]
href = Href(
- '/dashed/explore/{self.datasource.type}/'
+ '/caravel/explore/{self.datasource.type}/'
'{self.datasource.id}/'.format(**locals()))
return href(d)
@@ -725,7 +725,7 @@ class NVD3TimeSeriesViz(NVD3Viz):
df2 = self.get_df(query_object)
df2.index += delta
chart_data += self.to_series(
- df2, classed='dashed', title_suffix="---")
+ df2, classed='caravel', title_suffix="---")
chart_data = sorted(chart_data, key=lambda x: x['key'])
return chart_data
@@ -1077,7 +1077,7 @@ class WorldMapViz(BaseViz):
return qry
def get_data(self):
- from dashed.data import countries
+ from caravel.data import countries
df = self.get_df()
cols = [self.form_data.get('entity')]
metric = self.form_data.get('metric')
diff --git a/docs/Makefile b/docs/Makefile
index 7b78c404d..44dc5d1be 100644
--- a/docs/Makefile
+++ b/docs/Makefile
@@ -87,9 +87,9 @@ qthelp:
@echo
@echo "Build finished; now you can run "qcollectiongenerator" with the" \
".qhcp project file in $(BUILDDIR)/qthelp, like this:"
- @echo "# qcollectiongenerator $(BUILDDIR)/qthelp/dashed.qhcp"
+ @echo "# qcollectiongenerator $(BUILDDIR)/qthelp/caravel.qhcp"
@echo "To view the help file:"
- @echo "# assistant -collectionFile $(BUILDDIR)/qthelp/dashed.qhc"
+ @echo "# assistant -collectionFile $(BUILDDIR)/qthelp/caravel.qhc"
applehelp:
$(SPHINXBUILD) -b applehelp $(ALLSPHINXOPTS) $(BUILDDIR)/applehelp
@@ -104,8 +104,8 @@ devhelp:
@echo
@echo "Build finished."
@echo "To view the help file:"
- @echo "# mkdir -p $$HOME/.local/share/devhelp/dashed"
- @echo "# ln -s $(BUILDDIR)/devhelp $$HOME/.local/share/devhelp/dashed"
+ @echo "# mkdir -p $$HOME/.local/share/devhelp/caravel"
+ @echo "# ln -s $(BUILDDIR)/devhelp $$HOME/.local/share/devhelp/caravel"
@echo "# devhelp"
epub:
diff --git a/docs/_templates/layout.html b/docs/_templates/layout.html
index 8dc2374d4..4962dabdb 100644
--- a/docs/_templates/layout.html
+++ b/docs/_templates/layout.html
@@ -21,7 +21,7 @@
-
Dashed
+
Caravel
an open source data visualization platform
@@ -80,7 +80,7 @@
-
Dashed
+
Caravel
is an open source data visualization platform that provides easy
exploration of your data and allows you to create and share
diff --git a/docs/build.sh b/docs/build.sh
index ff54c955c..8347f2a47 100755
--- a/docs/build.sh
+++ b/docs/build.sh
@@ -1,6 +1,6 @@
#!/usr/bin/env bash
rm -rf _build
make html
-cp -r ../dashed/assets/images/ _build/html/_static/img/
-rm -rf /tmp/dashed-docs
-cp -r _build/html /tmp/dashed-docs
+cp -r ../caravel/assets/images/ _build/html/_static/img/
+rm -rf /tmp/caravel-docs
+cp -r _build/html /tmp/caravel-docs
diff --git a/docs/conf.py b/docs/conf.py
index 6be2338a5..c362857ad 100644
--- a/docs/conf.py
+++ b/docs/conf.py
@@ -1,6 +1,6 @@
# -*- coding: utf-8 -*-
#
-# dashed documentation build configuration file, created by
+# caravel documentation build configuration file, created by
# sphinx-quickstart on Thu Dec 17 15:42:06 2015.
#
# This file is execfile()d with the current directory set to its
@@ -51,7 +51,7 @@ source_suffix = '.rst'
master_doc = 'index'
# General information about the project.
-project = u'dashed'
+project = u'caravel'
copyright = u'2015, Maxime Beauchemin, Airbnb'
author = u'Maxime Beauchemin'
@@ -121,7 +121,7 @@ html_theme_path = sphinx_bootstrap_theme.get_html_theme_path()
# documentation.
html_theme_options = {
# 'bootswatch_theme': 'cosmo',
- 'navbar_title': 'Dashed Documentation',
+ 'navbar_title': 'Caravel Documentation',
'navbar_fixed_top': "false",
'navbar_sidebarrel': False,
'navbar_site_name': "Topics",
@@ -213,7 +213,7 @@ html_show_sourcelink = False
#html_search_scorer = 'scorer.js'
# Output file base name for HTML help builder.
-htmlhelp_basename = 'dasheddoc'
+htmlhelp_basename = 'caraveldoc'
# -- Options for LaTeX output ---------------------------------------------
@@ -235,7 +235,7 @@ latex_elements = {
# (source start file, target name, title,
# author, documentclass [howto, manual, or own class]).
latex_documents = [
- (master_doc, 'dashed.tex', u'Dashed Documentation',
+ (master_doc, 'caravel.tex', u'Caravel Documentation',
u'Maxime Beauchemin', 'manual'),
]
@@ -265,7 +265,7 @@ latex_documents = [
# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
- (master_doc, 'Dashed', u'dashed Documentation',
+ (master_doc, 'Caravel', u'caravel Documentation',
[author], 1)
]
@@ -279,8 +279,8 @@ man_pages = [
# (source start file, target name, title, author,
# dir menu entry, description, category)
texinfo_documents = [
- (master_doc, 'Dashed', u'Dashed Documentation',
- author, 'Dashed', 'One line description of project.',
+ (master_doc, 'Caravel', u'Caravel Documentation',
+ author, 'Caravel', 'One line description of project.',
'Miscellaneous'),
]
diff --git a/docs/index.rst b/docs/index.rst
index 037db7904..1008b7c22 100644
--- a/docs/index.rst
+++ b/docs/index.rst
@@ -1,5 +1,5 @@
.. warning:: This project used to be name Panoramix and has been renamed
- to Dashed in March 2016
+ to Caravel in March 2016
Overview
=======================================
diff --git a/docs/user_guide.rst b/docs/user_guide.rst
index 9844300a6..20758ff56 100644
--- a/docs/user_guide.rst
+++ b/docs/user_guide.rst
@@ -2,11 +2,11 @@ User Guide
==========
The user guide is a collection of short videos showing different aspect
-of Dashed.
+of Caravel.
Quick Intro
'''''''''''
-This video demonstrates how Dashed works at a high level, it shows how
+This video demonstrates how Caravel works at a high level, it shows how
to navigate through datasets and dashboards that are already available.
.. youtube:: https://www.youtube.com/watch?v=3Txm_nj_R7M
@@ -41,7 +41,7 @@ to toggle them on dashboards.
Adding a Table
''''''''''''''
-This videos shows you how to expose a new table in Dashed, and how to
+This videos shows you how to expose a new table in Caravel, and how to
define the semantics on how this can be accessed by others in the ``Explore``
and ``Dashboard`` views.
diff --git a/run_tests.sh b/run_tests.sh
index f04fa0a1b..5fb6ab7f4 100755
--- a/run_tests.sh
+++ b/run_tests.sh
@@ -1,5 +1,5 @@
#!/usr/bin/env bash
-rm /tmp/dashed_unittests.db
-export DASHED_CONFIG=tests.dashed_test_config
-dashed/bin/dashed db upgrade
+rm /tmp/caravel_unittests.db
+export CARAVEL_CONFIG=tests.caravel_test_config
+caravel/bin/caravel db upgrade
python setup.py nosetests
diff --git a/setup.cfg b/setup.cfg
index fefdc5c89..e59395f2e 100644
--- a/setup.cfg
+++ b/setup.cfg
@@ -1,5 +1,5 @@
[metadata]
-name = Dashed
+name = Caravel
summary = a data exploration platform
description-file = README.md
author = Maxime Beauchemin
@@ -7,7 +7,7 @@ author-email = maximebeauchemin@gmail.com
license = Apache License, Version 2.0
[files]
-packages = dashed
+packages = caravel
[build_sphinx]
source-dir = docs/
@@ -21,4 +21,4 @@ upload-dir = docs/_build/html
verbosity=1
detailed-errors=1
with-coverage=1
-cover-package=dashed
+cover-package=caravel
diff --git a/setup.py b/setup.py
index 90a252dfe..f5055fe9b 100644
--- a/setup.py
+++ b/setup.py
@@ -3,7 +3,7 @@ from setuptools import setup, find_packages
version = '0.8.4'
setup(
- name='dashed',
+ name='caravel',
description=(
"A interactive data visualization platform build on SqlAlchemy "
"and druid.io"),
@@ -11,7 +11,7 @@ setup(
packages=find_packages(),
include_package_data=True,
zip_safe=False,
- scripts=['dashed/bin/dashed'],
+ scripts=['caravel/bin/caravel'],
install_requires=[
'alembic>=0.8.5, <0.9.0',
'cryptography>=1.1.1, <2.0.0',
@@ -38,7 +38,7 @@ setup(
tests_require=['coverage'],
author='Maxime Beauchemin',
author_email='maximebeauchemin@gmail.com',
- url='https://github.com/airbnb/dashed',
+ url='https://github.com/airbnb/caravel',
download_url=(
- 'https://github.com/airbnb/dashed/tarball/' + version),
+ 'https://github.com/airbnb/caravel/tarball/' + version),
)
diff --git a/tests/caravel_test_config.py b/tests/caravel_test_config.py
new file mode 100644
index 000000000..14d9ef75f
--- /dev/null
+++ b/tests/caravel_test_config.py
@@ -0,0 +1,6 @@
+from caravel.config import *
+
+AUTH_USER_REGISTRATION_ROLE = 'alpha'
+SQLALCHEMY_DATABASE_URI = 'sqlite:////tmp/caravel_unittests.db'
+DEBUG = True
+CARAVEL_WEBSERVER_PORT = 8081
diff --git a/tests/core_tests.py b/tests/core_tests.py
index 41cf79c9e..dc35f6e28 100644
--- a/tests/core_tests.py
+++ b/tests/core_tests.py
@@ -2,13 +2,13 @@ import imp
import doctest
import os
import unittest
-os.environ['DASHED_CONFIG'] = 'tests.dashed_test_config'
+os.environ['CARAVEL_CONFIG'] = 'tests.caravel_test_config'
from flask.ext.testing import LiveServerTestCase, TestCase
-import dashed
-from dashed import app, db, models, utils
+import caravel
+from caravel import app, db, models, utils
BASE_DIR = app.config.get("BASE_DIR")
-cli = imp.load_source('cli', BASE_DIR + "/bin/dashed")
+cli = imp.load_source('cli', BASE_DIR + "/bin/caravel")
class LiveTest(TestCase):
@@ -22,7 +22,7 @@ class LiveTest(TestCase):
pass
def test_init(self):
- utils.init(dashed)
+ utils.init(caravel)
def test_load_examples(self):
cli.load_examples(sample=True)
@@ -39,7 +39,7 @@ class LiveTest(TestCase):
self.client.get(viz.get_json())
def test_csv(self):
- self.client.get('/dashed/explore/table/1/?viz_type=table&granularity=ds&since=100+years&until=now&metrics=count&groupby=name&limit=50&show_brush=y&show_brush=false&show_legend=y&show_brush=false&rich_tooltip=y&show_brush=false&show_brush=false&show_brush=false&show_brush=false&y_axis_format=&x_axis_showminmax=y&show_brush=false&line_interpolation=linear&rolling_type=None&rolling_periods=&time_compare=&num_period_compare=&where=&having=&flt_col_0=gender&flt_op_0=in&flt_eq_0=&flt_col_0=gender&flt_op_0=in&flt_eq_0=&slice_id=14&slice_name=Boys&collapsed_fieldsets=&action=&datasource_name=birth_names&datasource_id=1&datasource_type=table&previous_viz_type=line&csv=true')
+ self.client.get('/caravel/explore/table/1/?viz_type=table&granularity=ds&since=100+years&until=now&metrics=count&groupby=name&limit=50&show_brush=y&show_brush=false&show_legend=y&show_brush=false&rich_tooltip=y&show_brush=false&show_brush=false&show_brush=false&show_brush=false&y_axis_format=&x_axis_showminmax=y&show_brush=false&line_interpolation=linear&rolling_type=None&rolling_periods=&time_compare=&num_period_compare=&where=&having=&flt_col_0=gender&flt_op_0=in&flt_eq_0=&flt_col_0=gender&flt_op_0=in&flt_eq_0=&slice_id=14&slice_name=Boys&collapsed_fieldsets=&action=&datasource_name=birth_names&datasource_id=1&datasource_type=table&previous_viz_type=line&csv=true')
def test_dashboard(self):
for dash in db.session.query(models.Dashboard).all():
diff --git a/tests/dashed_test_config.py b/tests/dashed_test_config.py
deleted file mode 100644
index f61541e88..000000000
--- a/tests/dashed_test_config.py
+++ /dev/null
@@ -1,6 +0,0 @@
-from dashed.config import *
-
-AUTH_USER_REGISTRATION_ROLE = 'alpha'
-SQLALCHEMY_DATABASE_URI = 'sqlite:////tmp/dashed_unittests.db'
-DEBUG = True
-DASHED_WEBSERVER_PORT = 8081
diff --git a/tests/panoramix_test_config.py b/tests/panoramix_test_config.py
index ca643d5fb..dea0733b2 100644
--- a/tests/panoramix_test_config.py
+++ b/tests/panoramix_test_config.py
@@ -1,4 +1,4 @@
-from dashed.config import *
+from caravel.config import *
AUTH_USER_REGISTRATION_ROLE = 'alpha'
SQLALCHEMY_DATABASE_URI = 'sqlite:////tmp/panoramix_unittests.db'
diff --git a/dashed/assets/javascripts/modules/dashed.js b/caravel/assets/javascripts/modules/caravel.js
similarity index 98%
rename from dashed/assets/javascripts/modules/dashed.js
rename to caravel/assets/javascripts/modules/caravel.js
index 3b2ab4f21..acf2ab0ec 100644
--- a/dashed/assets/javascripts/modules/dashed.js
+++ b/caravel/assets/javascripts/modules/caravel.js
@@ -2,7 +2,7 @@ var $ = require('jquery');
var jQuery = $;
var d3 = require('d3');
-require('../../stylesheets/dashed.css');
+require('../../stylesheets/caravel.css');
// vis sources
var sourceMap = {
@@ -46,7 +46,7 @@ var color = function () {
// Color factory
var seen = {};
return function (s) {
// next line is for dashed series that should have the same color
s = s.replace('---', '');
if (seen[s] === undefined) {
seen[s] = Object.keys(seen).length;
@@ -133,7 +133,7 @@ var px = (function () {
}
function initFavStars() {
- var baseUrl = '/dashed/favstar/';
+ var baseUrl = '/caravel/favstar/';
// Init star behavihor for favorite
function show() {
if ($(this).hasClass('selected')) {
@@ -46,7 +46,7 @@ var color = function () {
var seen = {};
return function (s) {
- // next line is for dashed series that should have the same color
+ // next line is for caravel series that should have the same color
s = s.replace('---', '');
if (seen[s] === undefined) {
diff --git a/dashed/config.py b/caravel/config.py
similarity index 93%
rename from dashed/config.py
rename to caravel/config.py
index 31a799043..01876998d 100644
--- a/dashed/config.py
+++ b/caravel/config.py
@@ -1,4 +1,4 @@
"""The main config file for Dashed
All configuration in this file can be overridden by providing a local_config
in your PYTHONPATH as there is a ``from local_config import *``
@@ -12,13 +12,13 @@ BASE_DIR = os.path.abspath(os.path.dirname(__file__))
# ---------------------------------------------------------
# Dashed specifix config
# ---------------------------------------------------------
ROW_LIMIT = 50000
WEBSERVER_THREADS = 8
-DASHED_WEBSERVER_PORT = 8088
-DASHED_WEBSERVER_TIMEOUT = 60
+CARAVEL_WEBSERVER_PORT = 8088
+CARAVEL_WEBSERVER_TIMEOUT = 60
CUSTOM_SECURITY_MANAGER = None
# ---------------------------------------------------------
@@ -27,7 +27,7 @@ CUSTOM_SECURITY_MANAGER = None
SECRET_KEY = '\2\1thisismyscretkey\1\2\e\y\y\h' # noqa
# The SQLAlchemy connection string.
-SQLALCHEMY_DATABASE_URI = 'sqlite:////tmp/dashed.db'
+SQLALCHEMY_DATABASE_URI = 'sqlite:////tmp/caravel.db'
# SQLALCHEMY_DATABASE_URI = 'mysql://myapp@localhost/myapp'
# SQLALCHEMY_DATABASE_URI = 'postgresql://root:password@localhost/myapp'
@@ -44,7 +44,7 @@ SHOW_STACKTRACE = True
# GLOBALS FOR APP Builder
# ------------------------------
# Uncomment to setup Your App name
-APP_NAME = "Dashed"
+APP_NAME = "Caravel"
# Uncomment to setup Setup an App icon
# APP_ICON = "/static/img/something.png"
@@ -116,6 +116,6 @@ CACHE_DEFAULT_TIMEOUT = None
CACHE_CONFIG = {'CACHE_TYPE': 'null'}
try:
- from dashed_config import * # noqa
+ from caravel_config import * # noqa
except Exception:
pass
@@ -1,4 +1,4 @@
-"""The main config file for Dashed
+"""The main config file for Caravel
All configuration in this file can be overridden by providing a local_config
in your PYTHONPATH as there is a ``from local_config import *``
@@ -12,13 +12,13 @@ BASE_DIR = os.path.abspath(os.path.dirname(__file__))
# ---------------------------------------------------------
-# Dashed specifix config
+# Caravel specifix config
# ---------------------------------------------------------
ROW_LIMIT = 50000
diff --git a/dashed/data/__init__.py b/caravel/data/__init__.py
similarity index 99%
rename from dashed/data/__init__.py
rename to caravel/data/__init__.py
index 9fd40e12e..7d1f06994 100644
--- a/dashed/data/__init__.py
+++ b/caravel/data/__init__.py
@@ -1,4 +1,4 @@
"""Loads datasets, dashboards and slices in a new dashed instance"""
import gzip
import json
@@ -8,7 +8,7 @@ import textwrap
import pandas as pd
from sqlalchemy import String, DateTime, Float
-from dashed import app, db, models, utils
+from caravel import app, db, models, utils
# Shortcuts
DB = models.Database
@@ -1,4 +1,4 @@
-"""Loads datasets, dashboards and slices in a new dashed instance"""
+"""Loads datasets, dashboards and slices in a new caravel instance"""
import gzip
import json
diff --git a/dashed/data/birth_names.csv.gz b/caravel/data/birth_names.csv.gz
similarity index 100%
rename from dashed/data/birth_names.csv.gz
rename to caravel/data/birth_names.csv.gz
diff --git a/dashed/data/birth_names.json.gz b/caravel/data/birth_names.json.gz
similarity index 100%
rename from dashed/data/birth_names.json.gz
rename to caravel/data/birth_names.json.gz
diff --git a/dashed/data/countries.json.gz b/caravel/data/countries.json.gz
similarity index 100%
rename from dashed/data/countries.json.gz
rename to caravel/data/countries.json.gz
diff --git a/dashed/data/countries.md b/caravel/data/countries.md
similarity index 100%
rename from dashed/data/countries.md
rename to caravel/data/countries.md
diff --git a/dashed/data/countries.py b/caravel/data/countries.py
similarity index 100%
rename from dashed/data/countries.py
rename to caravel/data/countries.py
diff --git a/dashed/data/energy.json.gz b/caravel/data/energy.json.gz
similarity index 100%
rename from dashed/data/energy.json.gz
rename to caravel/data/energy.json.gz
diff --git a/dashed/forms.py b/caravel/forms.py
similarity index 98%
rename from dashed/forms.py
rename to caravel/forms.py
index c4df90b40..fe7146ba6 100644
--- a/dashed/forms.py
+++ b/caravel/forms.py
@@ -5,7 +5,7 @@ from wtforms import (
BooleanField, IntegerField, HiddenField)
from wtforms import validators, widgets
from copy import copy
-from dashed import app
+from caravel import app
from collections import OrderedDict
config = app.config
@@ -73,7 +73,7 @@ class FreeFormSelectField(SelectField):
class OmgWtForm(Form):
- """Dashedification of the WTForm Form object"""
+ """Caravelification of the WTForm Form object"""
fieldsets = {}
css_classes = dict()
@@ -101,13 +101,13 @@ class FormFactory(object):
def __init__(self, viz):
self.viz = viz
- from dashed.viz import viz_types
+ from caravel.viz import viz_types
viz = self.viz
datasource = viz.datasource
default_metric = datasource.metrics_combo[0][0]
default_groupby = datasource.groupby_column_names[0]
group_by_choices = [(s, s) for s in datasource.groupby_column_names]
# Pool of all the fields that can be used in Dashed
self.field_dict = {
'viz_type': SelectField(
'Viz',
@@ -180,7 +180,7 @@ class FormFactory(object):
('cca3', 'code ISO 3166-1 alpha-3 (cca3)'),
),
description=(
- "The country code standard that Dashed should expect "
+ "The country code standard that Caravel should expect "
"to find in the [country] column")),
'groupby': SelectMultipleSortableField(
'Group by',
@@ -581,7 +581,7 @@ class FormFactory(object):
"applies a date transformation to alter "
"your time column and defines a new time granularity."
"The options here are defined on a per database "
- "engine basis in the Dashed source code"))
+ "engine basis in the Caravel source code"))
add_to_form(time_fields)
field_css_classes['time_grain_sqla'] = ['form-control', 'select2']
field_css_classes['granularity_sqla'] = ['form-control', 'select2']
@@ -101,13 +101,13 @@ class FormFactory(object):
default_groupby = datasource.groupby_column_names[0]
group_by_choices = [(s, s) for s in datasource.groupby_column_names]
- # Pool of all the fields that can be used in Dashed
+ # Pool of all the fields that can be used in Caravel
self.field_dict = {
'viz_type': SelectField(
diff --git a/dashed/migrations/README b/caravel/migrations/README
similarity index 100%
rename from dashed/migrations/README
rename to caravel/migrations/README
diff --git a/dashed/migrations/__init__.py b/caravel/migrations/__init__.py
similarity index 100%
rename from dashed/migrations/__init__.py
rename to caravel/migrations/__init__.py
diff --git a/dashed/migrations/alembic.ini b/caravel/migrations/alembic.ini
similarity index 100%
rename from dashed/migrations/alembic.ini
rename to caravel/migrations/alembic.ini
diff --git a/dashed/migrations/env.py b/caravel/migrations/env.py
similarity index 100%
rename from dashed/migrations/env.py
rename to caravel/migrations/env.py
diff --git a/dashed/migrations/script.py.mako b/caravel/migrations/script.py.mako
similarity index 100%
rename from dashed/migrations/script.py.mako
rename to caravel/migrations/script.py.mako
diff --git a/dashed/migrations/versions/12d55656cbca_is_featured.py b/caravel/migrations/versions/12d55656cbca_is_featured.py
similarity index 100%
rename from dashed/migrations/versions/12d55656cbca_is_featured.py
rename to caravel/migrations/versions/12d55656cbca_is_featured.py
diff --git a/dashed/migrations/versions/18e88e1cc004_making_audit_nullable.py b/caravel/migrations/versions/18e88e1cc004_making_audit_nullable.py
similarity index 100%
rename from dashed/migrations/versions/18e88e1cc004_making_audit_nullable.py
rename to caravel/migrations/versions/18e88e1cc004_making_audit_nullable.py
diff --git a/dashed/migrations/versions/1a48a5411020_adding_slug_to_dash.py b/caravel/migrations/versions/1a48a5411020_adding_slug_to_dash.py
similarity index 100%
rename from dashed/migrations/versions/1a48a5411020_adding_slug_to_dash.py
rename to caravel/migrations/versions/1a48a5411020_adding_slug_to_dash.py
diff --git a/dashed/migrations/versions/1d2ddd543133_log_dt.py b/caravel/migrations/versions/1d2ddd543133_log_dt.py
similarity index 100%
rename from dashed/migrations/versions/1d2ddd543133_log_dt.py
rename to caravel/migrations/versions/1d2ddd543133_log_dt.py
diff --git a/dashed/migrations/versions/1e2841a4128_.py b/caravel/migrations/versions/1e2841a4128_.py
similarity index 100%
rename from dashed/migrations/versions/1e2841a4128_.py
rename to caravel/migrations/versions/1e2841a4128_.py
diff --git a/dashed/migrations/versions/2591d77e9831_user_id.py b/caravel/migrations/versions/2591d77e9831_user_id.py
similarity index 100%
rename from dashed/migrations/versions/2591d77e9831_user_id.py
rename to caravel/migrations/versions/2591d77e9831_user_id.py
diff --git a/dashed/migrations/versions/289ce07647b_add_encrypted_password_field.py b/caravel/migrations/versions/289ce07647b_add_encrypted_password_field.py
similarity index 100%
rename from dashed/migrations/versions/289ce07647b_add_encrypted_password_field.py
rename to caravel/migrations/versions/289ce07647b_add_encrypted_password_field.py
diff --git a/dashed/migrations/versions/2929af7925ed_tz_offsets_in_data_sources.py b/caravel/migrations/versions/2929af7925ed_tz_offsets_in_data_sources.py
similarity index 100%
rename from dashed/migrations/versions/2929af7925ed_tz_offsets_in_data_sources.py
rename to caravel/migrations/versions/2929af7925ed_tz_offsets_in_data_sources.py
diff --git a/dashed/migrations/versions/315b3f4da9b0_adding_log_model.py b/caravel/migrations/versions/315b3f4da9b0_adding_log_model.py
similarity index 100%
rename from dashed/migrations/versions/315b3f4da9b0_adding_log_model.py
rename to caravel/migrations/versions/315b3f4da9b0_adding_log_model.py
diff --git a/dashed/migrations/versions/430039611635_log_more.py b/caravel/migrations/versions/430039611635_log_more.py
similarity index 100%
rename from dashed/migrations/versions/430039611635_log_more.py
rename to caravel/migrations/versions/430039611635_log_more.py
diff --git a/dashed/migrations/versions/43df8de3a5f4_dash_json.py b/caravel/migrations/versions/43df8de3a5f4_dash_json.py
similarity index 100%
rename from dashed/migrations/versions/43df8de3a5f4_dash_json.py
rename to caravel/migrations/versions/43df8de3a5f4_dash_json.py
diff --git a/dashed/migrations/versions/4e6a06bad7a8_init.py b/caravel/migrations/versions/4e6a06bad7a8_init.py
similarity index 100%
rename from dashed/migrations/versions/4e6a06bad7a8_init.py
rename to caravel/migrations/versions/4e6a06bad7a8_init.py
diff --git a/dashed/migrations/versions/55179c7f25c7_sqla_descr.py b/caravel/migrations/versions/55179c7f25c7_sqla_descr.py
similarity index 100%
rename from dashed/migrations/versions/55179c7f25c7_sqla_descr.py
rename to caravel/migrations/versions/55179c7f25c7_sqla_descr.py
diff --git a/dashed/migrations/versions/5a7bad26f2a7_.py b/caravel/migrations/versions/5a7bad26f2a7_.py
similarity index 100%
rename from dashed/migrations/versions/5a7bad26f2a7_.py
rename to caravel/migrations/versions/5a7bad26f2a7_.py
diff --git a/dashed/migrations/versions/763d4b211ec9_fixing_audit_fk.py b/caravel/migrations/versions/763d4b211ec9_fixing_audit_fk.py
similarity index 100%
rename from dashed/migrations/versions/763d4b211ec9_fixing_audit_fk.py
rename to caravel/migrations/versions/763d4b211ec9_fixing_audit_fk.py
diff --git a/dashed/migrations/versions/7dbf98566af7_slice_description.py b/caravel/migrations/versions/7dbf98566af7_slice_description.py
similarity index 100%
rename from dashed/migrations/versions/7dbf98566af7_slice_description.py
rename to caravel/migrations/versions/7dbf98566af7_slice_description.py
diff --git a/dashed/migrations/versions/836c0bf75904_cache_timeouts.py b/caravel/migrations/versions/836c0bf75904_cache_timeouts.py
similarity index 100%
rename from dashed/migrations/versions/836c0bf75904_cache_timeouts.py
rename to caravel/migrations/versions/836c0bf75904_cache_timeouts.py
diff --git a/dashed/migrations/versions/8e80a26a31db_.py b/caravel/migrations/versions/8e80a26a31db_.py
similarity index 100%
rename from dashed/migrations/versions/8e80a26a31db_.py
rename to caravel/migrations/versions/8e80a26a31db_.py
diff --git a/dashed/migrations/versions/a2d606a761d9_adding_favstar_model.py b/caravel/migrations/versions/a2d606a761d9_adding_favstar_model.py
similarity index 100%
rename from dashed/migrations/versions/a2d606a761d9_adding_favstar_model.py
rename to caravel/migrations/versions/a2d606a761d9_adding_favstar_model.py
diff --git a/dashed/migrations/versions/d2424a248d63_.py b/caravel/migrations/versions/d2424a248d63_.py
similarity index 100%
rename from dashed/migrations/versions/d2424a248d63_.py
rename to caravel/migrations/versions/d2424a248d63_.py
diff --git a/dashed/migrations/versions/d827694c7555_css_templates.py b/caravel/migrations/versions/d827694c7555_css_templates.py
similarity index 100%
rename from dashed/migrations/versions/d827694c7555_css_templates.py
rename to caravel/migrations/versions/d827694c7555_css_templates.py
diff --git a/dashed/migrations/versions/fee7b758c130_.py b/caravel/migrations/versions/fee7b758c130_.py
similarity index 100%
rename from dashed/migrations/versions/fee7b758c130_.py
rename to caravel/migrations/versions/fee7b758c130_.py
diff --git a/dashed/models.py b/caravel/models.py
similarity index 98%
rename from dashed/models.py
rename to caravel/models.py
index 4142d8edc..e8973c489 100644
--- a/dashed/models.py
+++ b/caravel/models.py
@@ -1,4 +1,4 @@
"""A collection of ORM sqlalchemy models for Dashed"""
from copy import deepcopy, copy
from collections import namedtuple
@@ -29,8 +29,8 @@ from sqlalchemy.sql import table, literal_column, text, column
from sqlalchemy.sql.elements import ColumnClause
from sqlalchemy_utils import EncryptedType
-from dashed import app, db, get_session, utils
-from dashed.viz import viz_types
+from caravel import app, db, get_session, utils
+from caravel.viz import viz_types
from sqlalchemy.ext.declarative import declared_attr
config = app.config
@@ -186,7 +186,7 @@ class Slice(Model, AuditMixinNullable):
slice_params['slice_name'] = self.slice_name
from werkzeug.urls import Href
href = Href(
- "/dashed/explore/{self.datasource_type}/"
+ "/caravel/explore/{self.datasource_type}/"
"{self.datasource_id}/".format(self=self))
return href(slice_params)
@@ -229,7 +229,7 @@ class Dashboard(Model, AuditMixinNullable):
@property
def url(self):
- return "/dashed/dashboard/{}/".format(self.slug or self.id)
+ return "/caravel/dashboard/{}/".format(self.slug or self.id)
@property
def metadata_dejson(self):
@@ -352,7 +352,7 @@ class Database(Model, AuditMixinNullable):
@property
def sql_url(self):
- return '/dashed/sql/{}/'.format(self.id)
+ return '/caravel/sql/{}/'.format(self.id)
@property
def sql_link(self):
@@ -437,7 +437,7 @@ class SqlaTable(Model, Queryable, AuditMixinNullable):
@property
def table_link(self):
- url = "/dashed/explore/{self.type}/{self.id}/".format(self=self)
+ url = "/caravel/explore/{self.type}/{self.id}/".format(self=self)
return '{self.table_name}'.format(
url=url, self=self)
@@ -848,7 +848,7 @@ class DruidDatasource(Model, AuditMixinNullable, Queryable):
@property
def datasource_link(self):
- url = "/dashed/explore/{self.type}/{self.id}/".format(self=self)
+ url = "/caravel/explore/{self.type}/{self.id}/".format(self=self)
return '{self.datasource_name}'.format(
url=url, self=self)
@@ -884,7 +884,7 @@ class DruidDatasource(Model, AuditMixinNullable, Queryable):
@classmethod
def sync_to_db(cls, name, cluster):
"""Fetches metadata for that datasource and merges the Dashed db"""
print("Syncing Druid datasource [{}]".format(name))
session = get_session()
datasource = session.query(cls).filter_by(datasource_name=name).first()
@@ -1074,7 +1074,7 @@ class DruidDatasource(Model, AuditMixinNullable, Queryable):
class Log(Model):
"""ORM object used to log Dashed actions to the database"""
__tablename__ = 'logs'
@@ -1,4 +1,4 @@
-"""A collection of ORM sqlalchemy models for Dashed"""
+"""A collection of ORM sqlalchemy models for Caravel"""
from copy import deepcopy, copy
from collections import namedtuple
@@ -884,7 +884,7 @@ class DruidDatasource(Model, AuditMixinNullable, Queryable):
def sync_to_db(cls, name, cluster):
- """Fetches metadata for that datasource and merges the Dashed db"""
+ """Fetches metadata for that datasource and merges the Caravel db"""
print("Syncing Druid datasource [{}]".format(name))
session = get_session()
@@ -1074,7 +1074,7 @@ class DruidDatasource(Model, AuditMixinNullable, Queryable):
class Log(Model):
- """ORM object used to log Dashed actions to the database"""
+ """ORM object used to log Caravel actions to the database"""
__tablename__ = 'logs'
diff --git a/dashed/utils.py b/caravel/utils.py
similarity index 97%
rename from dashed/utils.py
rename to caravel/utils.py
index 1a7f8f457..9944be272 100644
--- a/dashed/utils.py
+++ b/caravel/utils.py
@@ -1,4 +1,4 @@
"""Utility functions used across Dashed"""
from datetime import datetime
import hashlib
@@ -169,11 +169,11 @@ class ColorFactory(object):
return self.BNB_COLORS[i % len(self.BNB_COLORS)]
-def init(dashed):
- """Inits the Dashed application with security roles and such"""
- db = dashed.db
- models = dashed.models
- sm = dashed.appbuilder.sm
+def init(caravel):
+ """Inits the Caravel application with security roles and such"""
+ db = caravel.db
+ models = caravel.models
+ sm = caravel.appbuilder.sm
alpha = sm.add_role("Alpha")
admin = sm.add_role("Admin")
@@ -1,4 +1,4 @@
-"""Utility functions used across Dashed"""
+"""Utility functions used across Caravel"""
from datetime import datetime
import hashlib
diff --git a/dashed/views.py b/caravel/views.py
similarity index 94%
rename from dashed/views.py
rename to caravel/views.py
index cec973b16..11f76f58d 100644
--- a/dashed/views.py
+++ b/caravel/views.py
@@ -1,4 +1,4 @@
"""Flask web views for Dashed"""
from datetime import datetime
import json
@@ -21,7 +21,7 @@ import pandas as pd
from sqlalchemy import select, text
from sqlalchemy.sql.expression import TextAsFrom
-from dashed import appbuilder, db, models, viz, utils, app, sm, ascii_art
+from caravel import appbuilder, db, models, viz, utils, app, sm, ascii_art
config = app.config
log_this = models.Log.log_this
@@ -44,11 +44,11 @@ class DeleteMixin(object):
return redirect(self.get_redirect())
-class DashedModelView(ModelView):
+class CaravelModelView(ModelView):
page_size = 500
-class TableColumnInlineView(CompactCRUDMixin, DashedModelView): # noqa
+class TableColumnInlineView(CompactCRUDMixin, CaravelModelView): # noqa
datamodel = SQLAInterface(models.TableColumn)
can_delete = False
edit_columns = [
@@ -69,7 +69,7 @@ appbuilder.add_view_no_menu(TableColumnInlineView)
-class DruidColumnInlineView(CompactCRUDMixin, DashedModelView): # noqa
+class DruidColumnInlineView(CompactCRUDMixin, CaravelModelView): # noqa
datamodel = SQLAInterface(models.DruidColumn)
edit_columns = [
'column_name', 'description', 'datasource', 'groupby',
@@ -86,7 +86,7 @@ class DruidColumnInlineView(CompactCRUDMixin, DashedModelView): # noqa
appbuilder.add_view_no_menu(DruidColumnInlineView)
-class SqlMetricInlineView(CompactCRUDMixin, DashedModelView): # noqa
+class SqlMetricInlineView(CompactCRUDMixin, CaravelModelView): # noqa
datamodel = SQLAInterface(models.SqlMetric)
list_columns = ['metric_name', 'verbose_name', 'metric_type']
edit_columns = [
@@ -97,7 +97,7 @@ class SqlMetricInlineView(CompactCRUDMixin, DashedModelView): # noqa
appbuilder.add_view_no_menu(SqlMetricInlineView)
-class DruidMetricInlineView(CompactCRUDMixin, DashedModelView): # noqa
+class DruidMetricInlineView(CompactCRUDMixin, CaravelModelView): # noqa
datamodel = SQLAInterface(models.DruidMetric)
list_columns = ['metric_name', 'verbose_name', 'metric_type']
edit_columns = [
@@ -112,15 +112,15 @@ class DruidMetricInlineView(CompactCRUDMixin, DashedModelView): # noqa
appbuilder.add_view_no_menu(DruidMetricInlineView)
-class DatabaseView(DashedModelView, DeleteMixin): # noqa
+class DatabaseView(CaravelModelView, DeleteMixin): # noqa
datamodel = SQLAInterface(models.Database)
list_columns = ['database_name', 'sql_link', 'created_by_', 'changed_on']
order_columns = utils.list_minus(list_columns, ['created_by_'])
add_columns = ['database_name', 'sqlalchemy_uri', 'cache_timeout']
search_exclude_columns = ('password',)
edit_columns = add_columns
- add_template = "dashed/models/database/add.html"
- edit_template = "dashed/models/database/edit.html"
+ add_template = "caravel/models/database/add.html"
+ edit_template = "caravel/models/database/edit.html"
base_order = ('changed_on', 'desc')
description_columns = {
'sqlalchemy_uri': (
@@ -147,7 +147,7 @@ appbuilder.add_view(
category_icon='fa-database',)
-class TableModelView(DashedModelView, DeleteMixin): # noqa
+class TableModelView(CaravelModelView, DeleteMixin): # noqa
datamodel = SQLAInterface(models.SqlaTable)
list_columns = [
'table_link', 'database', 'sql_link', 'is_featured',
@@ -190,7 +190,7 @@ appbuilder.add_view(
appbuilder.add_separator("Sources")
-class DruidClusterModelView(DashedModelView, DeleteMixin): # noqa
+class DruidClusterModelView(CaravelModelView, DeleteMixin): # noqa
datamodel = SQLAInterface(models.DruidCluster)
add_columns = [
'cluster_name',
@@ -210,7 +210,7 @@ if config['DRUID_IS_ACTIVE']:
category_icon='fa-database',)
-class SliceModelView(DashedModelView, DeleteMixin): # noqa
+class SliceModelView(CaravelModelView, DeleteMixin): # noqa
datamodel = SQLAInterface(models.Slice)
can_add = False
label_columns = {
@@ -252,7 +252,7 @@ class SliceAsync(SliceModelView): # noqa
appbuilder.add_view_no_menu(SliceAsync)
-class DashboardModelView(DashedModelView, DeleteMixin): # noqa
+class DashboardModelView(CaravelModelView, DeleteMixin): # noqa
datamodel = SQLAInterface(models.Dashboard)
label_columns = {
'created_by_': 'Creator',
@@ -301,7 +301,7 @@ class DashboardModelViewAsync(DashboardModelView): # noqa
appbuilder.add_view_no_menu(DashboardModelViewAsync)
-class LogModelView(DashedModelView):
+class LogModelView(CaravelModelView):
datamodel = SQLAInterface(models.Log)
list_columns = ('user', 'action', 'dttm')
edit_columns = ('user', 'action', 'dttm', 'json')
@@ -314,7 +314,7 @@ appbuilder.add_view(
icon="fa-list-ol")
-class DruidDatasourceModelView(DashedModelView, DeleteMixin): # noqa
+class DruidDatasourceModelView(CaravelModelView, DeleteMixin): # noqa
datamodel = SQLAInterface(models.DruidDatasource)
list_columns = [
'datasource_link', 'cluster', 'owner',
@@ -390,9 +390,9 @@ class R(BaseView):
appbuilder.add_view_no_menu(R)
-class Dashed(BaseView):
+class Caravel(BaseView):
- """The base views for Dashed!"""
+ """The base views for Caravel!"""
@has_access
@expose("/explore///")
@@ -463,9 +463,9 @@ class Dashed(BaseView):
mimetype="application/csv")
else:
if request.args.get("standalone") == "true":
- template = "dashed/standalone.html"
+ template = "caravel/standalone.html"
else:
- template = "dashed/explore.html"
+ template = "caravel/explore.html"
try:
resp = self.render_template(template, viz=obj, slice=slc)
@@ -646,7 +646,7 @@ class Dashed(BaseView):
int(o['slice_id']): o
for o in json.loads(dash.position_json)}
return self.render_template(
- "dashed/dashboard.html", dashboard=dash,
+ "caravel/dashboard.html", dashboard=dash,
templates=templates,
pos_dict=pos_dict)
@@ -661,7 +661,7 @@ class Dashed(BaseView):
table_name = request.args.get('table_name')
return self.render_template(
- "dashed/sql.html",
+ "caravel/sql.html",
tables=tables,
table_name=table_name,
db=mydb)
@@ -676,7 +676,7 @@ class Dashed(BaseView):
df = pd.DataFrame([(c['name'], c['type']) for c in cols])
df.columns = ['col', 'type']
return self.render_template(
- "dashed/ajah.html",
+ "caravel/ajah.html",
content=df.to_html(
index=False,
na_rep='',
@@ -695,7 +695,7 @@ class Dashed(BaseView):
[c.name for c in t.columns] or "*")
s = "SELECT\n{}\nFROM {}".format(fields, table_name)
return self.render_template(
- "dashed/ajah.html",
+ "caravel/ajah.html",
content=s
)
@@ -786,7 +786,7 @@ class Dashed(BaseView):
"Stacktrace is hidden. Change the SHOW_STACKTRACE "
"configuration setting to enable it")
return render_template(
- 'dashed/traceback.html',
+ 'caravel/traceback.html',
error_msg=error_msg,
title=ascii_art.stacktrace,
art=ascii_art.error), 500
@@ -795,21 +795,21 @@ class Dashed(BaseView):
@expose("/welcome")
def welcome(self):
"""Personalized welcome page"""
- return self.render_template('dashed/welcome.html', utils=utils)
+ return self.render_template('caravel/welcome.html', utils=utils)
-appbuilder.add_view_no_menu(Dashed)
+appbuilder.add_view_no_menu(Caravel)
if config['DRUID_IS_ACTIVE']:
appbuilder.add_link(
"Refresh Druid Metadata",
- href='/dashed/refresh_datasources/',
+ href='/caravel/refresh_datasources/',
category='Sources',
category_icon='fa-database',
icon="fa-cog")
-class CssTemplateModelView(DashedModelView, DeleteMixin):
+class CssTemplateModelView(CaravelModelView, DeleteMixin):
datamodel = SQLAInterface(models.CssTemplate)
list_columns = ['template_name']
edit_columns = ['template_name', 'css']
@@ -1,4 +1,4 @@
-"""Flask web views for Dashed"""
+"""Flask web views for Caravel"""
from datetime import datetime
import json